/*
 * ACTE4XX  Quad-T1/E1 PCI Driver
 *
 * Based on previous works, designs, and archetectures conceived and
 * written by Jim Dixon <jim@lambdatel.com> and Mark Spencer <markster@digium.com>.
 *
 * Copyright (C) 2001 Jim Dixon / Zapata Telephony.
 * Copyright (C) 2001-2005, Digium, Inc.
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. 
 *
 */

#include <linux/ioctl.h>

#define NUM_REGS 0xa9
#define NUM_PCI 12

struct acte4_regs {
	unsigned int key_high;
	unsigned int key_low;
	unsigned int serial;
	unsigned int date;	
};

#define AC4_GET_ALARMS  _IOW (ZT_CODE, 60, int)
#define AC4_GET_SLIPS	_IOW (ZT_CODE, 61, int)
#define AC4_GET_KEY     _IOW (ZT_CODE, 65, struct acte4_regs)

#define ACTE_CARD_ID		0x41434520		// "ACE "

#define AC_CAS_BASE			0x0080
#define AC_DATA_BASE		0x0100

#define AC_CARD_TYPE_REG	0x0001
#define AC_SPI_STA_REG		0x0002
#define AC_SPI_CTL_REG		0x0003
#define AC_E1_CONFIG_REG	0x0004
#define AC_E1_STATUS_REG	0x0005
#define AC_LEDS_REG			0x0006
#define AC_CLKSRC_REG		0x0007
#define AC_HWCONFIG_REG		0x0008
#define AC_KEY_LOW_REG		0x0009
#define AC_SERIAL_REG		0x0009
#define AC_KEY_HIGH_REG		0x000A
#define AC_USERRAND_REG		0x000A
#define AC_CNT_IRQ_REG		0x000B
#define AC_CNT_CV_REG		0x000C
#define AC_CNT_CRC_REG		0x000D
#define AC_CLEAR_IRQ_REG	0x000E
#define AC_CNT_SLIP_REG		0x000F

#define AC_IMPEDANCE_MASK	0x0100
#define AC_HWID_MASK		0x00F0
#define AC_DIP_MASK			0x000F

#define AC_USERRAND_MASK	0x0000FFFF
#define AC_USERRAND_ENABLE	0x00010000
	
#define AC_CLKSRC_MASK		0x07

#define AC_LINECODE_AMI		0x0100
#define AC_LIU_RESET_BIT	0x0200

#define AC_E1_AIS_STATUS	0x01
#define AC_E1_BFAE_STATUS	0x02
#define AC_E1_MFAE_STATUS	0x04
#define AC_E1_SYNC_STATUS	0x08
#define AC_E1_CAS_STATUS	0x10
#define AC_E1_LOS_STATUS	0x20
#define AC_E1_RAI_STATUS	0x40

#define AC_E1_RAI_CONFIG	0x01
#define AC_E1_LOOP_CONFIG	0x10
#define AC_E1_CASEN_CONFIG	0x20
#define AC_E1_PCM30_CONFIG	0x40
#define AC_E1_CRCEN_CONFIG	0x80

#define AC_SPI_FLAG_BUSY	0x00000200
#define AC_SPI_FLAG_WRITE	0x00000000
#define AC_SPI_FLAG_READ	0x00010000

#define AC_E2P_OPER_FLAG	0x8000
#define AC_E2P_ADDR_SERIAL	0x0060
#define AC_E2P_ADDR_DATE	0x0064
#define AC_E2P_PVDATA_REG	0x0050
#define AC_E2P_PVDADDR_REG	0x004E

#define AC_HWID_1E1_RJ		0x00
#define AC_HWID_1E1_BNC		0x01
#define AC_HWID_2E1_RJ		0x02
#define AC_HWID_2E1_BNC		0x03
#define AC_HWID_4E1_RJ		0x04
#define AC_HWID_4E1_BNC		0x05

